#! /usr/bin/perl

# author : stephane kattoor
# licensing : BSD

use strict;
use warnings;

use Getopt::Long;
use Pod::Usage;

use LWP::UserAgent;
use HTTP::Request::Common qw(POST GET);

use twitterParseContacts;

my $o_login;
my $o_password;
my $o_to;
my $o_text;

GetOptions(
	'login=s'		=>	\$o_login,
	'password=s'	=>	\$o_password,
	'to=s'		=>	\$o_to,
	'text=s'		=>	\$o_text	);

if (not $o_login or not $o_password or not $o_to or not $o_text) {
	pod2usage(1);
}

my $ua = LWP::UserAgent->new();
$ua->env_proxy();
$ua->cookie_jar({});

my $req = POST 'http://twitter.com/login', 
	[	username_or_email	=>	$o_login,
		password			=>	$o_password,
		commit				=> 'Sign In',	];
my $res = $ua->request($req);

$req = GET 'http://twitter.com/direct_messages';
print $req->as_string;
$res = $ua->request($req);
my $contactParser = twitterParseContacts->new();
$contactParser->parse($res->as_string);
my $contacts = $contactParser->getContacts;

if (not exists $contacts->{$o_to}) {
	die "$o_to is not one of your contacts. Stopped";
}

$req = POST 'http://twitter.com/direct_messages/create/' . $contacts->{$o_to},
	[		text	=>	$o_text,
			commit	=>	'Send',	];
$res = $ua->request($req);
print $res->as_string;
__END__

=head1 NAME

twitter-direct.pl - Sending Twitter direct messages at the command line

=head1 SYNOPSIS

twitter-direct.pl --login login --password password --to user --text "text to send"

=head1 OPTIONS

=over 4

=item B<--login>

lets you specify the login of your Twitter account

=item B<--password>

lets you specify your password

=item B<--to>

the target user of the message

=item B<--text>

the direct message to send

=back

=cut
